import json from '@rollup/plugin-json';
import strip from '@rollup/plugin-strip';
import babel from 'rollup-plugin-babel';
import localResolve from 'rollup-plugin-local-resolve';
import lessModules from 'rollup-plugin-less-modules';
import { uglify } from 'rollup-plugin-uglify';

const plugins = [
  babel({
    exclude: 'node_modules/**',
    presets: [
      [
        '@babel/env',
        {
          modules: false
        }
      ],
      '@babel/react'
    ],
    plugins: [
      '@babel/proposal-class-properties'
    ]
  }),
  localResolve(),
  lessModules({
    output: 'dist/blueprint-hooks-ui.css',
    sourcemap: false
  }),
  json()
]

if (process.env.NODE_ENV === 'production') {
  plugins.push(uglify());
  plugins.push(strip({
    functions: ['console.log', 'assert.*', 'debug', 'alert']
  }));
}

export default {
  input: './src/index.js',
  output: {
    file: './dist/index.js',
    format: 'umd',
    name: 'index',
    globals: {
      react: 'React',
      'react-dom': 'ReactDOM',
      'react-router-dom': 'reactRouterDom',
      'react-i18next': 'reactI18next',
      'react-use': 'reactUse',
      'react-hook-form': 'useForm',
      'rc-table': 'RcTable',
      'classnames': 'classNames',
      'prop-types': 'PropTypes',
      'axios': 'axios',
      'querystring': 'queryString',
      'lodash/isEmpty': 'isEmpty',
      'react-helmet': 'reactHelmet',
      'react-context-hooks-store': 'reactContextHooksStore',
      '@blueprintjs/core': 'blueprintjsCore',
      'react-dnd-html5-backend': 'HTML5Backend',
      'react-dnd': 'reactDnd',
      'localforage': 'localForage'
    }
  },
  external: [
    'react',
    'react-dom',
    'react-router-dom',
    'react-i18next',
    'react-use',
    'react-hook-form',
    'rc-table',
    'classnames',
    'prop-types',
    'axios',
    'querystring',
    'lodash/isEmpty',
    'react-helmet',
    'react-context-hooks-store',
    '@blueprintjs/core',
    'react-dnd-html5-backend',
    'react-dnd',
    'localforage'
  ],
  plugins
}
